@@ -6,9 +6,10 @@ huberM <-
 	     mu = if(is.null(weights)) median(x) else wgt.himedian(x, weights),
 	     s = if(is.null(weights)) mad(x, center=mu)
 		 else wgt.himedian(abs(x - mu), weights),
+	     se = FALSE,
 	     warn0scale = getOption("verbose"))
 {
-    ## Author: Martin Maechler, Date: 6 Jan 2003
+    ## Author: Martin Maechler, Date: 6 Jan 2003, ff
 
     ## implicit 'na.rm = TRUE':
     if(any(i <- is.na(x))) {
@@ -21,10 +22,13 @@ huberM <-
             stopifnot(is.numeric(weights), weights >= 0, length(weights) == n)
             sum(weights)
         } else n
-    it <- 0:0
+    it <- 0L
+    NA. <- NA_real_
     if(sum.w == 0) # e.g 'x' was all NA
-	return(list(mu = NA, s = NA, it = it)) # instead of error
+	return(list(mu = NA., s = NA., it = it, se = NA.)) # instead of error
 
+    if(se && !is.null(weights))
+	stop("Std.error computation not yet available for the case of 'weights'")
     if (s <= 0) {
         if(s < 0) stop("negative scale 's'")
         if(warn0scale && n > 1)
@@ -33,7 +37,7 @@ huberM <-
     else {
         wsum <- if(is.null(weights)) sum else function(u) sum(u * weights)
 	repeat {
-	    it <- it + 1:1
+	    it <- it + 1L
             y <- pmin(pmax(mu - k * s, x), mu + k * s)
 	    mu1 <- wsum(y) / sum.w
 	    if (abs(mu - mu1) < tol * s)
@@ -41,7 +45,8 @@ huberM <-
 	    mu <- mu1
 	}
     }
-    list(mu = mu, s = s, it = it)
+    list(mu = mu, s = s, it = it,
+         SE = if(se) s * sqrt(tauHuber(x, mu=mu, s=s, k=k) / n) else NA.)
 }
 
 ## this is a compatible improvement of MASS' huber() :
@@ -69,3 +74,18 @@ huber <- function (y, k = 1.5, tol = 1e-06)
     }
     list(mu = mu, s = s)
 }
+
+
+## Originally from  /u/ftp/NDK/Source-NDK-9/R/rg2-fkt.R :
+tauHuber <- function(x, mu, k=1.5, s = mad(x), resid = (x - mu)/s) {
+  ## Purpose: Korrekturfaktor Tau für die Varianz von Huber-M-Schätzern
+  ## -------------------------------------------------------------------------
+  ## Arguments: x = Daten mu = Lokations-Punkt k = Parameter der Huber Psi-Funktion
+  ## -------------------------------------------------------------------------
+  ## Author: Rene Locher Update: R. Frisullo 23.4.02;  M.Maechler (as.log(); s, resid)
+  inr <- abs(resid) <= k
+  psi  <- ifelse(inr, resid, sign(resid)*k)                # psi (x)
+  psiP <- as.logical(inr)# = ifelse(abs(resid) <= k, 1, 0) # psi'(x)
+  length(x) * sum(psi^2) / sum(psiP)^2
+}
+
