@@ -1,12 +1,10 @@
-#include <R.h>
-#include <Rinternals.h>
 
 #include <R_ext/Rdynload.h>
-
 #include "robustbase.h"
 
 
 #define CDEF(name)  {#name, (DL_FUNC) &name, sizeof(name ## _t)/sizeof(name ## _t[0]), name ##_t}
+#define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
 
 
 static R_NativePrimitiveArgType Qn0_t[] = {
@@ -46,18 +44,6 @@ static R_NativePrimitiveArgType R_lmrob_MM_t[] = {
     /* loss */ REALSXP, REALSXP, LGLSXP, INTSXP, INTSXP, INTSXP
 };
 
-static R_NativePrimitiveArgType R_psifun_t[] = {
-    REALSXP, REALSXP, INTSXP, INTSXP, INTSXP
-};
-
-static R_NativePrimitiveArgType R_chifun_t[] = {
-    REALSXP, REALSXP, INTSXP, INTSXP, INTSXP
-};
-
-static R_NativePrimitiveArgType R_wgtfun_t[] = {
-    REALSXP, REALSXP, INTSXP, INTSXP
-};
-
 static R_NativePrimitiveArgType R_find_D_scale_t[] = {
     REALSXP, REALSXP, REALSXP, INTSXP, REALSXP,
     /* c */ REALSXP, INTSXP, INTSXP, REALSXP,
@@ -96,9 +82,6 @@ static const R_CMethodDef CEntries[]  = {
     CDEF(wgt_himed),
     CDEF(R_lmrob_S),
     CDEF(R_lmrob_MM),
-    CDEF(R_psifun),
-    CDEF(R_chifun),
-    CDEF(R_wgtfun),
     CDEF(R_find_D_scale),
     CDEF(R_calc_fitted),
     CDEF(R_lmrob_M_S),
@@ -106,13 +89,17 @@ static const R_CMethodDef CEntries[]  = {
     {NULL, NULL, 0}
 };
 
-/* static R_CallMethodDef CallEntries[] = { */
-/*     {NULL, NULL, 0} */
-/* }; */
+static R_CallMethodDef CallEntries[] = {
+    CALLDEF(R_rho_inf, 2),
+    CALLDEF(R_psifun, 4),
+    CALLDEF(R_chifun, 4),
+    CALLDEF(R_wgtfun, 3),
+    {NULL, NULL, 0}
+};
 
 
 static R_FortranMethodDef FortEntries[] = {
-    {"rffastmcd", (DL_FUNC) &F77_SUB(rffastmcd), 48},/* ./rffastmcd.f */
+    {"rffastmcd", (DL_FUNC) &F77_SUB(rffastmcd), 47},/* ./rffastmcd.f */
     {"rfltsreg",  (DL_FUNC) &F77_SUB(rfltsreg), 42}, /* ./rfltsreg.f */
     {"rllarsbi",  (DL_FUNC) &F77_SUB(rllarsbi), 18}, /* ./rllarsbi.f */
     {NULL, NULL, 0}
@@ -120,7 +107,6 @@ static R_FortranMethodDef FortEntries[] = {
 
 void R_init_robustbase(DllInfo *dll)
 {
-    R_registerRoutines(dll, CEntries, NULL/*CallEntries*/,
-		       FortEntries, NULL);
+    R_registerRoutines(dll, CEntries, CallEntries, FortEntries, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
