@@ -152,9 +152,9 @@ stopifnot(all.equal(residuals(cm0),                      residuals(rm0)),
           all.equal(resid(cm1, type="pearson"),          resid(rm1, type="pearson")),
           all.equal(unclass(resid(cm2, type="pearson")), resid(rm2, type="pearson")))
 
-stopifnot(all.equal(vcov(cm0), vcov(rm0), check.attr=FALSE),
-          all.equal(vcov(cm1), vcov(rm1), check.attr=FALSE),
-          all.equal(vcov(cm2), vcov(rm2), check.attr=FALSE))
+stopifnot(all.equal(vcov(cm0), vcov(rm0), check.attributes=FALSE),
+          all.equal(vcov(cm1), vcov(rm1), check.attributes=FALSE),
+          all.equal(vcov(cm2), vcov(rm2), check.attributes=FALSE))
 
 ## Null fits (rank(X)==0) are tested in NAcoef.R
 
